@@ -4,6 +4,8 @@ pub mod partition;
 pub mod spg;
 pub mod message;
 pub mod connector;
+pub mod smartmodule;
+pub mod table;
 
 pub use fluvio_stream_model::core;
 
@@ -27,6 +29,8 @@ pub mod extended {
         Topic,
         Partition,
         ManagedConnector,
+        SmartModule,
+        Table,
     }
 
     pub trait SpecExt: Spec {
